@@ -7,7 +7,7 @@ use NEXT;
 use MRO::Compat;
 use warnings::register;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 {
     my %c3_mro_ok;
@@ -38,7 +38,8 @@ our $VERSION = '0.04';
 
             if (length $c3_mro_ok{$class} && $c3_mro_ok{$class}) {
                 unless ($warned_for{$class}) {
-                    warnings::warnif("${class} is trying to use NEXT, which is crap. use Class::C3 or Moose method modifiers instead.");
+                    warnings::warnif("${class} is trying to use NEXT, which is deprecated. "
+                        . "Please see the Class::C3::Adopt::NEXT documentation for details");
                     $warned_for{$class} = 1;
                 }
             }
@@ -55,6 +56,16 @@ our $VERSION = '0.04';
         *NEXT::ACTUAL::AUTOLOAD = \&NEXT::AUTOLOAD;
     }
 
+    sub import {
+        my ($class, @args) = @_;
+        my $target = caller();
+
+        for my $arg (@args) {
+            $warned_for{$target} = 1
+                if $arg eq '-no_warn';
+        }
+    }
+
     sub unimport {
         my $class = shift;
         @c3_mro_ok{@_} = ('') x @_;
@@ -74,12 +85,15 @@ Class::C3::Adopt::NEXT
     package MyApp::Plugin::FooBar;
     #use NEXT;
     use Class::C3::Adopt::NEXT;
+    # or 'use Class::C3::Adopt::NEXT' -no_warn to suppress warning
 
     sub a_method {
         my ($self) = @_;
         # Do some stuff
 
         # Re-dispatch method
+        # Note that this will generate a warning the _first_ time the package
+        # uses NEXT unless you un comment the 'no warnings' line above.
         $self->NEXT::method();
     }
 
@@ -99,6 +113,13 @@ interface, but using L<Class::C3> to do the hard work. You can then write new
 code without C<NEXT>, and migrate individual source files to use C<Class::C3> or
 method modifiers as appropriate, at whatever pace you're comfortable with.
 
+=head1 WARNINGS
+
+This module will warn once for each package using NEXT. It uses
+L<warnings::register>, and so can be disabled like by adding
+C<no warnings 'Class::C3::Adopt::NEXT';> to each package which generates a
+warning.
+
 =head1 MIGRATING
 
 There are two main reasons for using NEXT:
